==> file-roller-debuginfo-3.22.3-1.tar.xz: usr/src/debug/file-roller-3.22.3-1/src/fr-enum-types.c <==



#include <glib-object.h>
#include "fr-enum-types.h"

/* enumerations from "/usr/src/ports/file-roller/file-roller-3.22.3-1.i686/src/file-roller-3.22.3/src/typedefs.h" */
#include "/usr/src/ports/file-roller/file-roller-3.22.3-1.i686/src/file-roller-3.22.3/src/typedefs.h"
GType
fr_clipboard_op_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { FR_CLIPBOARD_OP_CUT, "FR_CLIPBOARD_OP_CUT", "cut" },
      { FR_CLIPBOARD_OP_COPY, "FR_CLIPBOARD_OP_COPY", "copy" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("FrClipboardOp", values);
  }
  return etype;
}
GType
fr_window_list_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { FR_WINDOW_LIST_MODE_FLAT, "FR_WINDOW_LIST_MODE_FLAT", "flat" },
      { FR_WINDOW_LIST_MODE_AS_DIR, "FR_WINDOW_LIST_MODE_AS_DIR", "as-dir" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("FrWindowListMode", values);
  }
  return etype;
}
GType
fr_compression_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { FR_COMPRESSION_VERY_FAST, "FR_COMPRESSION_VERY_FAST", "very-fast" },
      { FR_COMPRESSION_FAST, "FR_COMPRESSION_FAST", "fast" },
      { FR_COMPRESSION_NORMAL, "FR_COMPRESSION_NORMAL", "normal" },
      { FR_COMPRESSION_MAXIMUM, "FR_COMPRESSION_MAXIMUM", "maximum" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("FrCompression", values);
  }
  return etype;
}
GType
fr_overwrite_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { FR_OVERWRITE_YES, "FR_OVERWRITE_YES", "yes" },
      { FR_OVERWRITE_NO, "FR_OVERWRITE_NO", "no" },
      { FR_OVERWRITE_ASK, "FR_OVERWRITE_ASK", "ask" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("FrOverwrite", values);
  }
  return etype;
}

==> file-roller-debuginfo-3.24.1-1.tar.xz: usr/src/debug/file-roller-3.24.1-1/src/fr-enum-types.c <==



#include <glib-object.h>
#include "fr-enum-types.h"

/* enumerations from "/usr/src/ports/file-roller/file-roller-3.24.1-1.x86_64/src/file-roller-3.24.1/src/typedefs.h" */
#include "/usr/src/ports/file-roller/file-roller-3.24.1-1.x86_64/src/file-roller-3.24.1/src/typedefs.h"
GType
fr_clipboard_op_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { FR_CLIPBOARD_OP_CUT, "FR_CLIPBOARD_OP_CUT", "cut" },
      { FR_CLIPBOARD_OP_COPY, "FR_CLIPBOARD_OP_COPY", "copy" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("FrClipboardOp", values);
  }
  return etype;
}
GType
fr_window_list_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { FR_WINDOW_LIST_MODE_FLAT, "FR_WINDOW_LIST_MODE_FLAT", "flat" },
      { FR_WINDOW_LIST_MODE_AS_DIR, "FR_WINDOW_LIST_MODE_AS_DIR", "as-dir" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("FrWindowListMode", values);
  }
  return etype;
}
GType
fr_compression_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { FR_COMPRESSION_VERY_FAST, "FR_COMPRESSION_VERY_FAST", "very-fast" },
      { FR_COMPRESSION_FAST, "FR_COMPRESSION_FAST", "fast" },
      { FR_COMPRESSION_NORMAL, "FR_COMPRESSION_NORMAL", "normal" },
      { FR_COMPRESSION_MAXIMUM, "FR_COMPRESSION_MAXIMUM", "maximum" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("FrCompression", values);
  }
  return etype;
}
GType
fr_overwrite_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { FR_OVERWRITE_YES, "FR_OVERWRITE_YES", "yes" },
      { FR_OVERWRITE_NO, "FR_OVERWRITE_NO", "no" },
      { FR_OVERWRITE_ASK, "FR_OVERWRITE_ASK", "ask" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("FrOverwrite", values);
  }
  return etype;
}
